==> google-cloud-sdk-340.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/resource_settings/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The command group for the Resource Settings CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.ALPHA)
class ResourceSettings(base.Group):
  """Create and manage Resource Settings.

  The gcloud Resource Settings command group lets you create and manipulate
  resource settings.

  The Resource Settings Service is a hierarchy-aware service with a
  public-facing API for users to store settings that modify the behavior
  of their Google Cloud Platform resources, such as virtual machines,
  firewalls, projects, and so forth. Settings can be attached to
  organizations, folders, and projects, and can influence these resources
  as well as service resources that are descendants of the resource to which
  the settings are attached.
  """

  category = base.IDENTITY_AND_SECURITY_CATEGORY

  def Filter(self, context, args):
    del context, args
    base.EnableUserProjectQuotaWithFallback()

==> google-cloud-sdk-487.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/resource_settings/__init__.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The command group for the Resource Settings CLI."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import base


@base.Deprecate(
    is_removed=False,
    warning=('Resource Settings is deprecated. As of November 7, 2023, no '
             'organizations will be onboarded for any of the enabled settings, '
             'and the service will be shut down on October 1, 2024.'),
    error=('Resource Settings is deprecated, the service has been shut down on '
           'October 1, 2024.'))
@base.DefaultUniverseOnly
@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.ALPHA)
class ResourceSettings(base.Group):
  """Create and manage Resource Settings.

  The gcloud Resource Settings command group lets you create and manipulate
  resource settings.

  The Resource Settings Service is a hierarchy-aware service with a
  public-facing API for users to store settings that modify the behavior
  of their Google Cloud Platform resources, such as virtual machines,
  firewalls, projects, and so forth. Settings can be attached to
  organizations, folders, and projects, and can influence these resources
  as well as service resources that are descendants of the resource to which
  the settings are attached.
  """

  category = base.IDENTITY_AND_SECURITY_CATEGORY

  def Filter(self, context, args):
    # TODO(b/190539524):  Determine if command group works with project number
    base.RequireProjectID(args)
    del context, args
    base.EnableUserProjectQuotaWithFallback()
